@@ -3,7 +3,7 @@
 
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -822,41 +822,6 @@ namespace Oxygen
     typedef WindecoBorderKey WindecoTopBorderKey;
     typedef WindecoBorderKey WindecoBottomBorderKey;
 
-    //! key for dock widget button
-    class DockWidgetButtonKey
-    {
-        public:
-
-        //! constructor
-        DockWidgetButtonKey( const ColorUtils::Rgba& base, bool pressed, int size ):
-            _base(base.toInt()),
-            _pressed(pressed),
-            _size(size)
-        {}
-
-        //! equal to operator
-        bool operator == (const DockWidgetButtonKey& other) const
-        {
-            return _base == other._base &&
-                _pressed == other._pressed &&
-                _size == other._size;
-        }
-
-        //! less than operator
-        bool operator < (const DockWidgetButtonKey& other) const
-        {
-            if( _base != other._base ) return _base < other._base;
-            else if( _pressed != other._pressed ) return _pressed < other._pressed;
-            else return _size < other._size;
-        }
-
-        private:
-
-        guint32  _base;
-        bool _pressed;
-        int _size;
-    };
-
 }
 
 #endif
